@@ -34,7 +34,7 @@ def get_args():
     return args
 
 if __name__ == '__main__':
-    """ python gradcam.py -image-path <path_to_image>
+    """ python cam.py -image-path <path_to_image>
     Example usage of loading an image, and computing:
         1. CAM
         2. Guided Back Propagation
